
# Babel Protocol Commons

## Overview

This is an a set of common support classes that support the interaction between well known classes of distributed protocols and that allows the APIs of these protocols to be generic, allowing implementations to be agnostic to the concrete protocol that materializes a given abstraction.
The support classes are divided into three main packages, namely,  ````storage````, ````dissemination```` and ````membership````, that offer common APIs to the concrete protocols in each layer. Each package offers a set of requests, replies and notifications (as well as needed utils) abstractions to enable inter-protocol communication.

This repository will be continuously updated with further abstractions to enable the creation and integration of generic protocols into the Babel framework.
 
## Storage

### Requests

- *pt.unl.fct.di.novasys.babel.protocols.storage.requests.CreateKeySpaceRequest*:
Request to create a key space in a data magenement protocol, with a given set of ````properties````.
- *pt.unl.fct.di.novasys.babel.protocols.storage.requests.CreateCollectionRequest*:
Request to create a `collection`(aken to a table)  in a specific ````keySpace```` in a storage protocol, with a given set of ````properties````.
- *pt.unl.fct.di.novasys.babel.protocols.storage.requests.ExecuteRequest*:
Request to execute an operation on a specifc `keySpace` and `collection`. The operation in question is specified through the abstract class `CommonOperation` which can be instanciated with a specific operation type (i.e., `SmartContractOperation`, `PayloadOperation`, etc.). 
- *pt.unl.fct.di.novasys.babel.protocols.storage.requests.DeleteKeySpaceRequest*:
Request to delete a `keySpace`.
- *pt.unl.fct.di.novasys.babel.protocols.storage.requests.DeleteCollectionRequest*:
Request to delete a `collection`in a `keySpace `.

### Replies

- *pt.unl.fct.di.novasys.babel.protocols.storage.reply.CreateKeySpaceReply*:
Generated in response to a `CreateKeySpaceRequest`, with the status of the operation and an optional message.
- *pt.unl.fct.di.novasys.babel.protocols.storage.reply.CreateCollectionReply*:
Generated in response to a `CreateCollectionRequest`, with the status of the operation and an optional message.
- *pt.unl.fct.di.novasys.babel.protocols.storage.reply.ExecuteJSONReply*:
Generated in response to a `ExecuteRequest`, with the status of the operation and the response data (if any). This class parses the result as a JSON to be passed on to the application.
- *pt.unl.fct.di.novasys.babel.protocols.storage.reply.ExecutePayloadReply*:
Generated in response to a `ExecuteRequest`, with the status of the operation and the response data (if any). This class stores the result as a payload (a byte[]).
- *pt.unl.fct.di.novasys.babel.protocols.storage.reply.ExecuteSatusReply*:
Generated in response to a `ExecuteRequest`, with the status of the operation. This reply is meant for responses that don't contain any data.
- *pt.unl.fct.di.novasys.babel.protocols.storage.reply.DeleteKeySpaceReply*:
Generated in response to a `DeleteKeySpaceRequest`, with the status of the operation and an optional message.
- *pt.unl.fct.di.novasys.babel.protocols.storage.reply.DeleteCollectionReply*:
Generated in response to a `DeleteCollectionRequest`, with the status of the operation and an optional message.
- *pt.unl.fct.di.novasys.babel.protocols.storage.reply.NotSupportedReply*:
Generated in response to a request for an operation that is not implemented in the underneath storage protocol.

### Utils
The `storage` packages contains a list of utils, such as enumerators for list availabe status, data structures and operations, as well as helper classes to implement the operations issued by the application to the storage layer. More information can be found in the provided JavaDoc.

## Dissemination

### Requests and Replies
- *pt.unl.fct.di.novasys.babel.protocols.dissemination.requests.BrodcastRequest*:
Request to propagate a broadcast message (in the name of an Host) with the provided `payload` and a specific`TTL`.

### Notifications
- *pt.unl.fct.di.novasys.babel.protocols.dissemination.notifications.BrodcastDelivery*:
Indicates that a broadcast message with a `payload` as been received.

## Membership


### Requests and Replies

- *pt.unl.fct.di.novasys.babel.protocols.membership.requests.GetNeighborsSampleRequest*:
Request to get a sample of neighbors (Host format) from the Active view up to a number (provided in the message).
- *pt.unl.fct.di.novasys.babel.protocols.membership.requests.GetNeighborsSampleReply*:
Generated in response to the previous request.

### Notifications

- *pt.unl.fct.di.novasys.babel.protocols.membership.notifications.NeighborUp*:
indicated the Host of a local neighbor that became available 
- *pt.unl.fct.di.novasys.babel.protocols.membership.notifications.NeighborDown*:
indicates the Host of a local neighbor that is no longer available



## Authors

João Leitão (jc.leitao@fct.unl.pt)

Diogo Jesus (da.jesus@campus.fct.unl.pt)

# Installation

### Dependencies

Copy and paste the following block inside your ```pom.xml dependencies``` block.

```
<dependency>
	<groupId>pt.unl.fct.di.novasys.babel</groupId>
	<artifactId>babel-protocol-commons</artifactId>
	<version>[1.0.2,)</version>
</dependency>
```


### Repository Setup

If you haven't already done so, you will need to add the following to your ```pom.xml``` file.

```
<repositories>
    <repository>
        <id>novasys-mvn</id>
        <url>https://novasys.di.fct.unl.pt/packages/mvn</url>
    </repository>
</repositories>
```
