package pt.unl.fct.di.novasys.babel.protocols.membership;

import java.io.IOException;
import java.net.InetAddress;
import java.util.Objects;
import java.util.UUID;

import io.netty.buffer.ByteBuf;
import pt.unl.fct.di.novasys.network.ISerializer;
import pt.unl.fct.di.novasys.network.data.Host;

public class Peer extends Host implements Cloneable {

	public final static int BYTES = 6 + 16;
	private final UUID peerID;

	public Peer(InetAddress address, int port) {
		super(address, port);
		this.peerID = UUID.randomUUID();
	}

	public Peer(InetAddress address, int port, UUID peerID) {
		super(address, port);
		this.peerID = peerID;
	}

	private Peer(Host h, UUID peerID) {
		super(h.getAddress(), h.getPort());
		this.peerID = peerID;
	}

	private Peer(Host h) {
		super(h.getAddress(), h.getPort());
		this.peerID = UUID.randomUUID();
	}

	public UUID getPeerID() {
		return peerID;
	}

	@Override
	public String toString() {
		return this.peerID + " (" + super.toString() + ")";
	}

	@Override
	public boolean equals(Object other) {
		if (other == this)
			return true;
		if (!(other instanceof Host))
			return false;
		return super.equals(other) && ((other instanceof Peer) ? this.peerID.equals(((Peer) other).peerID) : true);
	}

	@Override
	public int hashCode() {
		return Objects.hash(this.getPort(), this.getAddress(), peerID.toString());
	}

	// Assume always a valid IPv4 address
	public int compareTo(Peer other) {

		int cmp = Long.compare(this.peerID.getMostSignificantBits(), other.peerID.getMostSignificantBits());
		if (cmp != 0)
			return cmp;

		return Long.compare(this.peerID.getLeastSignificantBits(), other.peerID.getLeastSignificantBits());
	}

	public static ISerializer<Peer> serializer = new ISerializer<Peer>() {
		@Override
		public void serialize(Peer peer, ByteBuf out) throws IOException {
			Host.serializer.serialize(peer, out);
			out.writeLong(peer.peerID.getMostSignificantBits());
			out.writeLong(peer.peerID.getLeastSignificantBits());
		}

		@Override
		public Peer deserialize(ByteBuf in) throws IOException {
			Host h = Host.serializer.deserialize(in);
			UUID id = new UUID(in.readLong(), in.readLong());
			return new Peer(h, id);
		}
	};

	public Peer clone() {
		return new Peer(this.getAddress(), this.getPort(), this.peerID);
	}

}
