package pt.unl.fct.di.novasys.babel.protocols.secure.membership;

import java.io.IOException;
import java.net.InetAddress;
import java.util.Objects;

import io.netty.buffer.ByteBuf;
import pt.unl.fct.di.novasys.babel.internal.security.PeerIdEncoder;
import pt.unl.fct.di.novasys.network.ISerializer;
import pt.unl.fct.di.novasys.network.data.Bytes;
import pt.unl.fct.di.novasys.network.data.Host;

public class Peer implements Cloneable, Comparable<Peer> {

    private final Bytes identity;

    private Host host;

    public Peer(byte[] identity, InetAddress address, int port) {
        this(Bytes.of(identity), address, port);
    }

    public Peer(Bytes identity, InetAddress address, int port) {
        this.identity = identity;
        this.host = new Host(address, port);
    }

    public Peer(byte[] identity, Host host) {
        this(Bytes.of(identity), host);
    }

    public Peer(Bytes identity, Host host) {
        this.host = host;
        this.identity = identity;
    }

    public void setHost(Host newHost) {
        this.host = newHost;
    }

    public void setHost(InetAddress address, int port) {
        this.host = new Host(address, port);
    }

    public byte[] getIdentity() {
        return identity.array();
    }

    public Host getHost() {
        return host;
    }

    public InetAddress getAddress() {
        return host.getAddress();
    }

    public int getPort() {
        return host.getPort();
    }

    @Override
    public boolean equals(Object other) {
        return other == this
                || (other instanceof Peer peer
                        ? this.identity.equals(peer.identity)
                        : false);
    }

    @Override
    public int hashCode() {
        return Objects.hash(host, identity);
    }

    @Override
    public Peer clone() {
        return new Peer(identity.clone(), host.getAddress(), host.getPort());
    }

    // Assume always a valid IPv4 address
    @Override
    public int compareTo(Peer other) {
        return this.identity.compareTo(other.identity);
    }

    public static ISerializer<Peer> serializer = new ISerializer<Peer>() {
        @Override
        public void serialize(Peer peer, ByteBuf out) throws IOException {
            out.writeInt(peer.identity.length())
                .writeBytes(peer.identity.array());
            Host.serializer.serialize(peer.getHost(), out);
        }

        @Override
        public Peer deserialize(ByteBuf in) throws IOException {
            byte[] id = new byte[in.readInt()];
            in.readBytes(id);
            Host host = Host.serializer.deserialize(in);

            return new Peer(id, host);
        }
    };

    @Override
    public String toString() {
        return PeerIdEncoder.encodeToString(identity.array()) + " (" + host + ")";
    }

}
