package pt.unl.fct.di.novasys.babel.protocols.storage.replies;

import pt.unl.fct.di.novasys.babel.protocols.storage.replies.common.CommonReply;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationStatus;

/**
 * A reply issued by a creation of a collection in a given keySpace. The reply
 * contains the identifers of the collection and the respective keySpace, as
 * well information about the status of the operation issued in the
 * corresponding request, as well as an optional message detailing the result.
 */
public class CreateCollectionReply extends CommonReply {
	public final static short REPLY_ID = 602;

	private String collectionID;
	private String keySpace;

	/**
	 * Creates a create collection reply with a given status.
	 * 
	 * @param status the status of the reply.
	 */
	public CreateCollectionReply(CommonOperationStatus status) {
		super(status, REPLY_ID);

		this.keySpace = null;
		this.collectionID = null;
	}

	/**
	 * Creates a create collection reply with a given status an a message detailing
	 * the status.
	 * 
	 * @param status  the status of the reply.
	 * @param message a message detailing the status.
	 */
	public CreateCollectionReply(CommonOperationStatus status, String message) {
		super(status, message, REPLY_ID);

		this.keySpace = null;
		this.collectionID = null;
	}

	/**
	 * Creates a create collection reply with a given status, as well as the
	 * keySpace and collection identifiers.
	 * 
	 * @param keySpace     keySpace of the creating created
	 * @param collectionID the collection identifier
	 * @param status       the status of the reply.
	 */
	public CreateCollectionReply(String keySpace, String collectionID, CommonOperationStatus status) {
		super(status, REPLY_ID);

		this.keySpace = keySpace;
		this.collectionID = collectionID;
	}

	/**
	 * Creates a create collection reply with a given status, as well as the
	 * keySpace and collection identifiers. The message should contain the details
	 * of the status passed.
	 * 
	 * @param keySpace     keySpace of the creating created
	 * @param collectionID the collection identifier
	 * @param status       the status of the reply.
	 * @param message      a message detailing the status.
	 * 
	 */
	public CreateCollectionReply(String keySpace, String collectionID, CommonOperationStatus status, String message) {
		super(status, message, REPLY_ID);

		this.keySpace = keySpace;
		this.collectionID = collectionID;
	}

	/**
	 * Gets the collection identifier, if one as passed.
	 * @return the collection identifier, or null, if none was passed in the constructor.
	 */
	public String getCollectionID() {
		return collectionID;
	}

	/**
	 * Gets the keySpace identifier of the collection, if one as passed.
	 * @return the keySpace identifier, or null, if none was passed in the constructor.
	 */
	public String getKeySpace() {
		return keySpace;
	}

}
