package pt.unl.fct.di.novasys.babel.protocols.storage.replies;

import pt.unl.fct.di.novasys.babel.protocols.storage.replies.common.CommonReply;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationStatus;

/**
 * A reply issued by a creation of a keySpace. The reply contains the identifers
 * of the the respective keySpace, as well information about the status of the
 * operation issued in the corresponding request, as well as an optional message
 * detailing the result.
 */
public class CreateKeySpaceReply extends CommonReply {
	public final static short REPLY_ID = 601;
	private String keySpace;

	/**
	 * Creates a create key space reply with a given status.
	 * 
	 * @param status the status of the reply.
	 */
	public CreateKeySpaceReply(CommonOperationStatus status) {
		super(status, REPLY_ID);

		this.keySpace = null;
	}

	/**
	 * Creates a create key space reply with a given status an a message detailing
	 * the status.
	 * 
	 * @param status  the status of the reply.
	 * @param message a message detailing the status.
	 */
	public CreateKeySpaceReply(CommonOperationStatus status, String message) {
		super(status, message, REPLY_ID);

		this.keySpace = null;
	}

	/**
	 * Creates a create key space reply with a given status, as well as the keySpace
	 * identifier.
	 * 
	 * @param keySpace keySpace of the creating created
	 * @param status   the status of the reply.
	 */
	public CreateKeySpaceReply(String keySpace, CommonOperationStatus status) {
		super(status, REPLY_ID);

		this.keySpace = keySpace;
	}

	/**
	 * Creates a create key space reply with a given status, as well as the keySpace
	 * identifier. The message should contain the details of the status passed.
	 * 
	 * @param keySpace keySpace of the creating created
	 * @param status   the status of the reply. * @param message a message detailing
	 *                 the status.
	 * @param message  a message detailing the status.
	 * 
	 * 
	 */
	public CreateKeySpaceReply(String keySpace, CommonOperationStatus status, String message) {
		super(status, message, REPLY_ID);

		this.keySpace = keySpace;
	}

	/**
	 * Gets the keySpace identifier of the collection, if one as passed.
	 * 
	 * @return the keySpace identifier, or null, if none was passed in the
	 *         constructor.
	 */
	public String getKeySpace() {
		return keySpace;
	}

}
