package pt.unl.fct.di.novasys.babel.protocols.storage.replies;

import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationStatus;

/**
 * A reply issued by the deletion of a collection in a given keySpace. The reply
 * contains the identifers of the collection and the respective keySpace, as
 * well information about the status of the operation issued in the
 * corresponding request, as well as an optional message detailing the result.
 */
public class DeleteCollectionReply extends CreateCollectionReply {
	public final static short REPLY_ID = 604;

	/**
	 * Creates a delete key space reply with a given status.
	 * 
	 * @param status the status of the reply.
	 */
	public DeleteCollectionReply(CommonOperationStatus status) {
		super(status);

	}

	/**
	 * Creates a delete key space eply with a given status an a message detailing
	 * the status.
	 * 
	 * @param status  the status of the reply.
	 * @param message a message detailing the status.
	 */
	public DeleteCollectionReply(CommonOperationStatus status, String message) {
		super(status, message);

	}

	/**
	 * Creates a delete key space reply with a given status, as well as the keySpace
	 * and collection identifier.
	 * 
	 * @param keySpace     keySpace of the creating created
	 * @param collectionID the identifier of the collection
	 * @param status       the status of the reply.
	 */
	public DeleteCollectionReply(String keySpace, String collectionID, CommonOperationStatus status) {
		super(keySpace, collectionID, status);

	}

	/**
	 * Creates a delete key space reply with a given status, as well as the keySpace
	 * and collection identifier. The message should contain the details of the
	 * status passed.
	 * 
	 * @param keySpace     keySpace of the creating created
	 * @param status       the status of the reply. * @param message a message
	 *                     detailing the status.
	 * @param message      a message detailing the status.
	 * @param collectionID the identifier of the collection
	 * 
	 * 
	 * 
	 */
	public DeleteCollectionReply(String keySpace, String collectionID, CommonOperationStatus status, String message) {
		super(keySpace, collectionID, status, message);
	}

}
