package pt.unl.fct.di.novasys.babel.protocols.storage.replies;

import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationStatus;

/**
 * A reply issued by a removal of a keySpace. The reply contains the identifiers
 * of the the respective keySpace, as well information about the status of the
 * operation issued in the corresponding request, as well as an optional message
 * detailing the result.
 */
public class DeleteKeySpaceReply extends CreateKeySpaceReply {
	public final static short REPLY_ID = 603;

	/**
	 * Creates a delete key space reply with a given status.
	 * 
	 * @param status the status of the reply.
	 */
	public DeleteKeySpaceReply(CommonOperationStatus status) {
		super(status);
	}

	/**
	 * Creates a delete key space eply with a given status and a message detailing
	 * the status.
	 * 
	 * @param status  the status of the reply.
	 * @param keySpace     keySpace of the creating created
	 */
	public DeleteKeySpaceReply(String keySpace, CommonOperationStatus status) {
		super(keySpace, status);

	}

	/**
	 * Creates a delete key space reply with a given status, as well as the keySpace
	 * and collection identifier and a message detailing the status.
	 * 
	 * @param keySpace keySpace of the creating created
	 * @param status   the status of the reply.
	 * @param message  a message detailing the status.
	 * 
	 */
	public DeleteKeySpaceReply(String keySpace, CommonOperationStatus status, String message) {
		super(keySpace, status, message);
	}

}
