package pt.unl.fct.di.novasys.babel.protocols.storage.replies;

import pt.unl.fct.di.novasys.babel.protocols.storage.replies.common.CommonExecuteReply;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationStatus;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationType;

/**
 * A reply of an operation parsed as simple byte array. It stores information
 * about the result of the operation as well as the type of operation (e.g.,
 * READ, UPDATE, etc.) issued.
 */
public class ExecutePayloadReply extends CommonExecuteReply {
	public final static short REPLY_ID = 606;
	private byte[] data;

	/**
	 * Creates a execute payload reply with the status of the operation, the type of
	 * operation issued, and the data representing the result.
	 * 
	 * @param status     the status of the operation.
	 * @param type       the type of operation committed.
	 * @param data       the result of the operation.
	 * @param keySpace   the keySpace where the operation was executed
	 * @param collection the collection where the operation was executed
	 * @param objectID   the identifier of the object
	 */
	public ExecutePayloadReply(CommonOperationStatus status, CommonOperationType type, String keySpace,
			String collection, String objectID, byte[] data) {
		super(status, type, keySpace, collection, objectID, REPLY_ID);

		this.data = data;
	}

	/**
	 * Creates a execute payload reply with the status of the operation, the type of
	 * operation issued, and the data representing the result. No information about
	 * the keySpace or collection is passed.
	 * 
	 * @param status the status of the operation.
	 * @param type   the type of operation committed.
	 * @param data   the result of the operation.
	 */
	public ExecutePayloadReply(CommonOperationStatus status, CommonOperationType type, byte[] data) {
		super(status, type, null, null, null, REPLY_ID);

		this.data = data;
	}

	/**
	 * Creates a execute payload reply with the status of the operation, the type of
	 * operation issued, and the data representing the result.The message should
	 * detail the status of the operation.
	 * 
	 * @param status     the status of the operation.
	 * @param type       the type of operation committed.
	 * @param data       the result of the operation.
	 * @param message    a message detailing the status.
	 * @param keySpace   the keySpace where the operation was executed
	 * @param collection the collection where the operation was executed
	 * @param objectID   the identifier of the object
	 * 
	 */
	public ExecutePayloadReply(CommonOperationStatus status, CommonOperationType type, String keySpace,
			String collection, String objectID, String message, byte[] data) {
		super(status, type, keySpace, collection, objectID, REPLY_ID);

		this.data = data;
	}

	/**
	 * Gets the payload of the reply (i.e., the response data)
	 * 
	 * @return the payload of the reply.
	 */
	public byte[] getPayload() {
		return data;
	}
}
