package pt.unl.fct.di.novasys.babel.protocols.storage.replies;

import pt.unl.fct.di.novasys.babel.protocols.storage.replies.common.CommonExecuteReply;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationStatus;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationType;

/**
 * A reply of an operation not supported by the storage layer. It stores the
 * status of the operation, it's type, and an optional message containing the
 * details of the status.
 */
public class NotSupportedReply extends CommonExecuteReply {
	public final static short REPLY_ID = 605;

	/**
	 * Creates a not supported reply, with the type of operation issued on the
	 * request. Since a status is not passed, the class assumes the default OK.
	 * 
	 * @param type       the type of operation issued.
	 * @param keySpace   the keySpace where the operation was executed
	 * @param collection the collection where the operation was executed
	 * @param objectID   the identifier of the object
	 */
	public NotSupportedReply(CommonOperationType type, String keySpace, String collection, String objectID) {
		super(CommonOperationStatus.NOT_SUPPORTED, type, keySpace, collection, objectID, REPLY_ID);
	}

	/**
	 * Creates a not supported reply, with the type of operation issued on the
	 * request, as well as the status of the operation.
	 * 
	 * @param type       the type of operation issued.
	 * @param status     the status of the operation.
	 * @param keySpace   the keySpace where the operation was executed
	 * @param collection the collection where the operation was executed
	 * @param objectID   the identifier of the object
	 */
	public NotSupportedReply(CommonOperationStatus status, CommonOperationType type, String keySpace, String collection,
			String objectID) {
		super(status, type, keySpace, collection, objectID, REPLY_ID);
	}

	/**
	 * Creates a not supported reply, with the type of operation issued on the
	 * request, as well as the status of the operation. The message should contain
	 * details about the status passed.
	 * 
	 * @param type       the type of operation issued.
	 * @param status     the status of the operation.
	 * @param message    a message detailing the status.
	 * @param keySpace   the keySpace where the operation was executed
	 * @param collection the collection where the operation was executed
	 * @param objectID   the identifier of the object
	 * 
	 */
	public NotSupportedReply(CommonOperationStatus status, CommonOperationType type, String keySpace, String collection,
			String objectID, String message) {
		super(status, type, keySpace, collection, objectID, REPLY_ID);
	}

}
