package pt.unl.fct.di.novasys.babel.protocols.storage.replies.common;

import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationStatus;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationType;

/**
 * An abstract class common to all execute replies issued by the storage layer.
 * Execute replies englobe all the operations performed on the objects of the
 * storage layer, such as insertions, reads, deletes, etc. This class stores the
 * operation type being issued by the reply (e.g., CREATE, UPDATE, READ, etc.).
 * The class is an extension of the CommonReply abstract class.
 */
public abstract class CommonExecuteReply extends CommonReply {
	private CommonOperationType type;
	private String keySpace;
	private String collection;
	private String objectID;

	public CommonExecuteReply(CommonOperationStatus status, CommonOperationType type, String keySpace,
			String collection, String objectID, short protoID) {
		super(status, protoID);

		this.type = type;
		this.keySpace = keySpace;
		this.collection = collection;
		this.objectID = objectID;
	}

	public CommonExecuteReply(CommonOperationStatus status, CommonOperationType type, String keySpace,
			String collection, String objectID, String message, short protoID) {
		super(status, message, protoID);

		this.type = type;
		this.type = type;
		this.keySpace = keySpace;
		this.collection = collection;
		this.objectID = objectID;
	}

	/**
	 * Gets the operation type of the reply.
	 * 
	 * @return the operation type.
	 */
	public CommonOperationType getOperationType() {
		return type;
	}

	public String getKeySpace() {
		return keySpace;
	}

	public String getCollection() {
		return collection;
	}

	public String getObjectID() {
		return objectID;
	}

}
