package pt.unl.fct.di.novasys.babel.protocols.storage.replies.common;

import pt.unl.fct.di.novasys.babel.generic.ProtoReply;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationStatus;

/**
 * An abstract class common to all replies issued by the storage layer. This
 * class stores the status of the operation (i.e., OK, ERROR, CONFLICT, etc.),
 * as well as an optional message explaining the reply status.
 */
public abstract class CommonReply extends ProtoReply {
	private CommonOperationStatus status;
	private String message;

	public CommonReply(CommonOperationStatus status, short protoID) {
		super(protoID);

		this.status = status;
		this.message = null;
	}

	public CommonReply(CommonOperationStatus status, String message, short protoID) {
		super(protoID);

		this.status = status;
		this.message = message;
	}

	/**
	 * Gets the reply status (e.g., OK, ERROR, NOT_SUPPORTED, etc.)
	 * 
	 * @return the reply status.
	 */
	public CommonOperationStatus getStatus() {
		return status;
	}

	/**
	 * Gets an optional message detailing the reply status. If no message was passed
	 * in the constructor, a null is returned.
	 * 
	 * @return the message if one is available or null otherwise.
	 */
	public String getMessage() {
		return message;
	}

}
