package pt.unl.fct.di.novasys.babel.protocols.storage.requests;

import java.util.Properties;

import pt.unl.fct.di.novasys.babel.protocols.storage.requests.common.CommonRequest;

/**
 * A request issued by the application to create a collection in a given
 * keyspace. The request contains information about the keyspace in question as
 * well as the collection that is going to be created.
 */
public class CreateCollectionRequest extends CommonRequest {
	public final static short REQUEST_ID = 602;

	private Properties properties;
	private String collection;

	/**
	 * Creates a create collection request with the keyspace, the collection identifier and a set of optional properties
	 * for the creation of he collection.
	 * @param keySpace the keyspace of the collection.
	 * @param collection the collection identifier.
	 * @param properties optional properties for the creation of the collection.
	 */
	public CreateCollectionRequest(String keySpace, String collection, Properties properties) {
		super(keySpace, REQUEST_ID);

		this.collection = collection;
		this.properties = properties;
	}
	
	/**
	 * Creates a create collection request with the keyspace, the collection identifier and a set of optional properties
	 * for the creation of he collection.
	 * @param keySpace the keyspace of the collection.
	 * @param collection the collection identifier.
	 */
	public CreateCollectionRequest(String keySpace, String collection) {
		super(keySpace, REQUEST_ID);

		this.collection = collection;
		this.properties = new Properties();
	}

	
	/**
	 * Gets the properties for the creation of the collection.
	 * If no properties were passed in the constructor, this method returns null.
	 * @return the properties of the collection, or null if none were passed in the constructor.
	 */
	public Properties getProperties() {
		return properties;
	}

	/**
	 * Gets the collection identifier.
	 * @return the collection identifier.
	 */
	public String getCollection() {
		return collection;
	}
}
