package pt.unl.fct.di.novasys.babel.protocols.storage.requests;

import java.util.Properties;

import pt.unl.fct.di.novasys.babel.protocols.storage.requests.common.CommonRequest;

/**
 * A request issued by the application to create a keyspace. The request
 * contains information about the keyspace in question and a set of optional
 * properties for the creation of the keyspace.
 */
public class CreateKeySpaceRequest extends CommonRequest {
	public final static short REQUEST_ID = 601;

	private Properties properties;

	/**
	 * Creates a create collection request with the keyspace, and a set of optional
	 * properties for the creation of the collection.
	 * 
	 * @param keySpace   the keyspace of the collection.
	 * @param properties optional properties for the creation of the collection.
	 */
	public CreateKeySpaceRequest(String keySpace, Properties properties) {
		super(keySpace, REQUEST_ID);

		this.properties = properties;
	}

	/**
	 * Gets the properties for the creation of the collection. If no properties were
	 * passed in the constructor, this method returns null.
	 * 
	 * @return the properties of the collection, or null if none were passed in the
	 *         constructor.
	 */
	public Properties getProperties() {
		return properties;
	}

}
