package pt.unl.fct.di.novasys.babel.protocols.storage.requests;

import pt.unl.fct.di.novasys.babel.protocols.storage.requests.common.CommonRequest;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.common.CommonOperation;

/*
 * TODO
 * - Add abstraction to enable multiple request on different storage systems (blockchain, key-value, rdbms etc.)
 */

/**
 * A request issued by the application to perform an operation (e.g., UPDATE,
 * CREATE, READ, etc.) on a specific collection of a keySpace. the request
 * receives information about the keySpace and collection identifiers, as well
 * as an object containing the information about the operation to be executed.
 * The operation is represented to a CommonOperation abstract class that can be
 * instantiated through different types of operations for specific storage
 * solutions (i.e., Blockchain, RDBMS, etc.). For more informations check the
 * storage.utils.operation package.
 */
public class ExecuteRequest extends CommonRequest {
	public final static short REQUEST_ID = 603;

	private String collection;
	private CommonOperation operation;

	/**
	 * Creates an execute request operation on a given keyspace and collection. The
	 * operation argument should contain information about the operation being
	 * issued by the application. This object can be instanciated as one of the
	 * concrete implementations offered in the storage.utils.operation package.
	 * 
	 * @param keySpace   the keySpace of the operation
	 * @param collection the collection of the operation
	 * @param operation  the data of the operation
	 */
	public ExecuteRequest(String keySpace, String collection, CommonOperation operation) {
		super(keySpace, REQUEST_ID);

		this.collection = collection;
		this.operation = operation;
	}

	/**
	 * Gets the collection identifier.
	 * 
	 * @return the collection identifier.
	 */
	public String getCollection() {
		return collection;
	}

	/**
	 * Gets the operation to be executed
	 * 
	 * @return the operation to be executed.
	 */
	public CommonOperation getOperation() {
		return operation;
	}

}
