package pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations;

import java.util.Map;
import java.util.Map.Entry;

import com.datastax.oss.driver.internal.core.type.PrimitiveType;

import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.common.CommonOperation;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationType;

/**
 * An operation to be issued to a Cassandra storage layer. The operation
 * contains a Map where the keys represent the column names, and the value - a
 * Entry(PrimitiveType,Object) - where the first element of the pair represents
 * the data type and the second element the value to be passed onto the column.
 * 
 */
public class CassandraOperation extends CommonOperation {
	private Map<String, Entry<PrimitiveType, Object>> tableColumns;

	/**
	 * Creates a Cassandra operation, with the specific type and the the associated
	 * data (represented as columns).
	 * 
	 * @param operationType the type of operation
	 * @param tableColumns  the data associated with the operation
	 */
	public CassandraOperation(CommonOperationType operationType,
			Map<String, Entry<PrimitiveType, Object>> tableColumns) {
		super(operationType);
		this.tableColumns = tableColumns;
	}

	/**
	 * Gets the columns to be updated on the operation. The Map has the following
	 * structure - where the keys represent the column names, and the value - a
	 * Entry(PrimitiveType,Object) - where the first element of the pair represents
	 * the data type and the second element the value to be passed onto the column.
	 * 
	 * @return
	 */
	public Map<String, Entry<PrimitiveType, Object>> getTableColumns() {
		return tableColumns;
	}

	/**
	 * Gets the data associated with the column
	 * 
	 * @param columnKey the column key
	 * @return the data associated with the column
	 */
	public Object getColumn(String columnKey) {
		return tableColumns.get(columnKey);
	}

}
