package pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations;

import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationType;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.ConditionsOnObjects;

/**
 * An operation with a payload (represented as a byte[]) as well as set of conditions (i.e., a selector) 
 * to be applied to the objects.
 */
public class OperationWithConditions extends PayloadOperation {
	private ConditionsOnObjects conditions;
	
	/**
	 * Creates a operation with conditions, and a payload containing the data.
	 * @param type the type of the operation
	 * @param conditions the conditions to be applied to the objects
	 * @param payload a payload containing the data.
	 */
	public OperationWithConditions(CommonOperationType type, ConditionsOnObjects conditions, byte [] payload) {
		super(type,payload);
		
		this.conditions=conditions;
	}

	/**
	 * Get the conditions to be performed on the objects.
	 * @return the conditions to be performed on the objects.
	 */
	public ConditionsOnObjects getConditions() {
		return conditions;
	}
}
