package pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations;

import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.common.CommonOperation;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationType;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.types.ReplicatedStructuresOperations.ReplicatedDataTypes;

/**
 * An operation to create a replicated object on the storage layer. The
 * operation contains the type of operation being issued (e.g., CREATE) as well
 * as the type of replicated data structure to be created (e.g., SET, LIST,
 * etc.)
 */
public class ReplicatedCreateStructOperation extends CommonOperation {
	private ReplicatedDataTypes dataStructType;
	private Object initialValue;
	private String objectID;

	/**
	 * Creates a replicated create operation, with the operation type and the type
	 * of data structure.
	 * 
	 * @param opType         the type of the operation
	 * @param dataStructType the type of the data structure to be created.
	 * @param initialValue   an optional initial value to put in the data structure
	 */
	public ReplicatedCreateStructOperation(CommonOperationType opType, ReplicatedDataTypes dataStructType,
			Object initialValue) {
		super(opType);

		this.dataStructType = dataStructType;
		this.initialValue = initialValue;
		this.objectID = null;
	}

	/**
	 * Creates a replicated create operation, with the operation type and the type
	 * of data structure.
	 * 
	 * @param opType         the type of the operation
	 * @param dataStructType the type of the data structure to be created.
	 * @param initialValue   an optional initial value to put in the data structure
	 * @param objectID    the unique identifier of the structure
	 */
	public ReplicatedCreateStructOperation(CommonOperationType opType, ReplicatedDataTypes dataStructType,
			Object initialValue, String objectID) {
		super(opType);

		this.dataStructType = dataStructType;
		this.initialValue = initialValue;
		this.objectID = objectID;
	}

	public ReplicatedDataTypes getDataType() {
		return dataStructType;
	}

	public Object getInitialValue() {
		return initialValue;
	}

	public String getObjectID() {
		return objectID;
	}
}
