package pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations;

import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.common.CommonOperation;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationType;

/**
 * An operation to delete a replicated data structure on the storage layer. The
 * operation contains the type of operation being issued (e.g., CREATE) as well
 * as the unique identifier of the structure.
 */
public class ReplicatedDelStructOperation extends CommonOperation {
	private String objectID;

	/**
	 * Creates a replicated create operation, with the operation type and the
	 * identifier of the structure.
	 * 
	 * @param opType   the type of the operation
	 * @param objectID the identifier of the data structure to be deleted.
	 */
	public ReplicatedDelStructOperation(CommonOperationType opType, String objectID) {
		super(opType);

		this.objectID = objectID;
	}

	/**
	 * Gets the identifier of the structure to be deleted.
	 * 
	 * @return the identifier of the structure.
	 */
	public String getObjectID() {
		return objectID;
	}
}