package pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;

import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.common.CommonOperation;
import pt.unl.fct.di.novasys.babel.protocols.storage.utils.operations.utils.CommonOperationType;


/**
 * An operation issued to blockchain storage layer, realized internally by a smart contract.
 * This class receives an operation type (e.g., CREATE, UPDATE, READ, etc.) and a Map of pairs (String,String) representing the key of the object
 * and its associated values (represented as a string value).
 */
public class SmartContractOperation extends CommonOperation {
	private Map<String,String> args;
	
	/**
	 * Creates a blockchain operation with a specific operation type, and the arguments (containing the values) to be passed on to the smart contract.
	 * @param type the type of the operation
	 * @param args arguments of the operation
	 */
	public SmartContractOperation(CommonOperationType type, Map<String,String> args) {
		super(type);
		
		this.args=args;
	}

	/**
	 * Gets all of the arguments to be applied on the smart contract.
	 * @return the arguments to be applied on the smart contract.
	 */
	public Map<String, String> getArgs() {
		return args;
	}
	
	/**
	 * Gets the argument keys (i.e., the identifiers of the objects in the smart contract).
	 * @return the argument keys (i.e., the identifiers of the objects in the smart contract).
	 */
	public Set<String> getArgsIdentifiers(){
		return args.keySet();
	}
	
	/**
	 * Gets the values associated with the argument keys.
	 * @return the values associated with the argument keys.
	 */
	public List<String> getArgsValues(){
		return new ArrayList<>(args.values());
	}

}
