package pt.unl.fct.di.novasys.babel.protocols.storage.utils.types;

/**
 * An enumerator that contains the set of generic replicated data structures
 * list available in the library, as well as the operations allowed for each
 * one.
 */
public enum ReplicatedStructuresOperations {
	SET_ADD(ReplicatedDataTypes.SET, StructureOperationTypes.ADD),
	SET_REMOVE(ReplicatedDataTypes.SET, StructureOperationTypes.REMOVE),
	SET_LOOKUP(ReplicatedDataTypes.SET, StructureOperationTypes.LOOKUP),
	SET_ITERATOR(ReplicatedDataTypes.SET, StructureOperationTypes.ITERATOR),

	MAP_PUT(ReplicatedDataTypes.MAP, StructureOperationTypes.PUT),
	MAP_GET(ReplicatedDataTypes.MAP, StructureOperationTypes.GET),
	MAP_DEL(ReplicatedDataTypes.MAP, StructureOperationTypes.DELETE),
	MAP_ITERATOR(ReplicatedDataTypes.MAP, StructureOperationTypes.ITERATOR),

	REGISTER_ASSIGN(ReplicatedDataTypes.REGISTER, StructureOperationTypes.ASSIGN),
	REGISTER_GET(ReplicatedDataTypes.REGISTER, StructureOperationTypes.GET),

	COUNTER_INC(ReplicatedDataTypes.COUNTER, StructureOperationTypes.INC),
	COUNTER_DEC(ReplicatedDataTypes.COUNTER, StructureOperationTypes.DEC),
	COUNTER_GET(ReplicatedDataTypes.COUNTER, StructureOperationTypes.GET),

	LIST_INSERT_AT(ReplicatedDataTypes.LIST, StructureOperationTypes.INSERT_AT),
	LIST_GET_AT(ReplicatedDataTypes.LIST, StructureOperationTypes.GET_AT),
	LIST_REMOVE_AT(ReplicatedDataTypes.LIST, StructureOperationTypes.REMOVE_AT),
	LIST_GET(ReplicatedDataTypes.LIST, StructureOperationTypes.GET),
	
	FLAG_ENABLE(ReplicatedDataTypes.FLAG,StructureOperationTypes.ENABLE),
	FLAG_DISABLE(ReplicatedDataTypes.FLAG,StructureOperationTypes.DISABLE),
	FLAG_GET(ReplicatedDataTypes.FLAG,StructureOperationTypes.GET);


	private ReplicatedDataTypes dataType;
	private StructureOperationTypes opType;

	ReplicatedStructuresOperations(ReplicatedDataTypes dataType, StructureOperationTypes opType) {
		this.dataType = dataType;
		this.opType = opType;
	}

	/**
	 * Gets the replicated data type associated with the operation.
	 * @return the replicated data type associated with the operation.
	 */
	public ReplicatedDataTypes getDataType() {
		return dataType;
	}

	/**
	 * Gets the operation being performed on the data structure.
	 * @return the operation being performed on the data structure.
	 */
	public StructureOperationTypes OperationType() {
		return opType;
	}

	/**
	 * An enumerator containing the replicated data structures available in the
	 * library.
	 */
	public enum ReplicatedDataTypes {
		SET, MAP, REGISTER, LIST, COUNTER, FLAG;
	}

	/**
	 * An enumerator containing the generic operations available on top of the
	 * replicated data structures.
	 */
	public enum StructureOperationTypes {
		ADD, REMOVE, LOOKUP, ITERATOR, ASSIGN, GET, PUT, DELETE, INC, DEC, INSERT_AT, REMOVE_AT, GET_AT,ENABLE,DISABLE;
	}
}
